@@ -12,7 +12,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: holidays.c 7060 2012-07-14 16:32:11Z storner $";
+static char rcsid[] = "$Id: holidays.c 7240 2013-07-29 04:26:20Z storner $";
 
 #include <time.h>
 #include <sys/time.h>
@@ -672,10 +672,16 @@ int main(int argc, char *argv[])
 			}
 		}
 		else {
-			int year = atoi(hset);
+			char *set_tok, *y_tok;
+			int year;
+
+			set_tok = strtok(hset, " ");
+			y_tok = strtok(NULL, " ");
+			year = atoi(y_tok);
+
 			load_holidays(year);
-			printholidays(hset, sbuf);
-			printf("Holidays in set: %s\n", STRBUF(sbuf));
+			printholidays(set_tok, sbuf, 0, 11);
+			printf("Holidays year %d in set: %s\n", year, STRBUF(sbuf));
 			clearstrbuffer(sbuf);
 		}
 	} while (1);
