@@ -13,7 +13,7 @@
 /*----------------------------------------------------------------------------*/
 
 
-static char rcsid[] = "$Id: loadhosts.c 7644 2015-05-01 02:44:02Z jccleaver $";
+static char rcsid[] = "$Id: loadhosts.c 7720 2015-11-04 20:23:13Z jccleaver $";
 
 #include <stdio.h>
 #include <string.h>
@@ -126,6 +126,8 @@ static void xmh_item_list_setup(void)
 	xmh_item_name[XMH_DEPENDS]             = "XMH_DEPENDS";
 	xmh_item_key[XMH_BROWSER]              = "browser=";
 	xmh_item_name[XMH_BROWSER]             = "XMH_BROWSER";
+	xmh_item_key[XMH_HTTPHEADERS]              = "httphdr=";
+	xmh_item_name[XMH_HTTPHEADERS]             = "XMH_HTTPHEADERS";
 	xmh_item_key[XMH_HOLIDAYS]             = "holidays=";
 	xmh_item_name[XMH_HOLIDAYS]            = "XMH_HOLIDAYS";
 	xmh_item_key[XMH_DELAYRED]             = "delayred=";
@@ -168,6 +170,8 @@ static void xmh_item_list_setup(void)
 	xmh_item_name[XMH_FLAG_HIDEHTTP]       = "XMH_FLAG_HIDEHTTP";
 	xmh_item_key[XMH_PULLDATA]             = "PULLDATA";
 	xmh_item_name[XMH_PULLDATA]            = "XMH_PULLDATA";
+	xmh_item_key[XMH_NOFLAP]               = "NOFLAP";
+	xmh_item_name[XMH_NOFLAP]              = "XMH_NOFLAP";
 	xmh_item_key[XMH_FLAG_MULTIHOMED]      = "MULTIHOMED";
 	xmh_item_name[XMH_FLAG_MULTIHOMED]     = "XMH_MULTIHOMED";
 	xmh_item_key[XMH_FLAG_HTTP_HEADER_MATCH]             = "headermatch";
@@ -192,6 +196,8 @@ static void xmh_item_list_setup(void)
 	xmh_item_name[XMH_COMPACT]             = "XMH_COMPACT";
 	xmh_item_key[XMH_INTERFACES]           = "INTERFACES:";
 	xmh_item_name[XMH_INTERFACES]          = "XMH_INTERFACES";
+	xmh_item_key[XMH_ACCEPT_ONLY]          = "ACCEPTONLY:";
+	xmh_item_name[XMH_ACCEPT_ONLY]         = "XMH_ACCEPT_ONLY";
 
 	xmh_item_name[XMH_IP]                  = "XMH_IP";
 	xmh_item_name[XMH_CLIENTALIAS]         = "XMH_CLIENTALIAS";
@@ -205,6 +211,7 @@ static void xmh_item_list_setup(void)
 	xmh_item_name[XMH_DGNAME]              = "XMH_DGNAME";
 	xmh_item_name[XMH_PAGEINDEX]           = "XMH_PAGEINDEX";
 	xmh_item_name[XMH_RAW]                 = "XMH_RAW";
+	xmh_item_name[XMH_DATA]                = "XMH_DATA";
 
 	i = 0; while (xmh_item_key[i]) i++;
 	if (i != XMH_IP) {
@@ -605,6 +612,12 @@ char *xmh_item(void *hostin, enum xmh_item_t item)
 		  if (p == NULL) p = xmh_find_item(host, XMH_FLAG_NOBB2);
 		  return p;
 
+	  case XMH_NOFLAP:
+		  /* special - can be 'noflap=test1,test2' or just 'noflap' */
+		  p = xmh_find_item(host, XMH_NOFLAP);
+		  if ((p != NULL) && (*(p) == '\0')) p = xmh_item_key[XMH_NOFLAP];	/* mirror flag semantics */
+		  return p;
+
 	  case XMH_PULLDATA:
 		  /* special - can be 'pulldata=IP:PORT' or just 'pulldata' */
 		  p = xmh_find_item(host, XMH_PULLDATA);
