@@ -8,7 +8,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: ackinfo.c 7892 2016-02-08 21:03:53Z jccleaver $";
+static char rcsid[] = "$Id: ackinfo.c 7949 2016-03-03 23:44:55Z jccleaver $";
 
 #include <string.h>
 #include <stdlib.h>
@@ -97,10 +97,14 @@ int main(int argc, char *argv[])
 	{
 	    char cgisource[1024]; char *p;
 	    p = csp_header("ackinfo"); if (p) fprintf(stdout, "%s", p);
-	    snprintf(cgisource, sizeof(cgisource), "%s/%s", xgetenv("SECURECGIBINURL"), "criticalview");
+	    snprintf(cgisource, sizeof(cgisource), "%s/%s", xgetenv("CGIBINURL"), "svcstatus");
 	    if (!cgi_refererok(cgisource)) {
-		fprintf(stdout, "Location: %s.sh?\n\n", cgisource);
-		return 0;
+		snprintf(cgisource, sizeof(cgisource), "%s/%s", xgetenv("CGIBINURL"), "criticalview");
+		if (!cgi_refererok(cgisource)) {
+			errprintf("ackinfo POST that is not coming from criticalview or svcstatus (referer=%s). Ignoring.\n", textornull(getenv("HTTP_REFERER")) );
+			fprintf(stdout, "Location: %s.sh?\n\n", cgisource);
+			return 0;
+		}
 	    }
 	}
 
