@@ -8,7 +8,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char vmstat_rcsid[] = "$Id: do_vmstat.c 7026 2012-07-13 14:05:20Z storner $";
+static char vmstat_rcsid[] = "$Id: do_vmstat.c 7334 2014-01-07 21:52:08Z storner $";
 
 typedef struct vmstat_layout_t {
 	int index;
@@ -116,7 +116,7 @@ static vmstat_layout_t vmstat_irix_layout[] = {
 
 /* This one matches FreeBSD 4.10 */
 /* LARRD 0.43c compatible */
-static vmstat_layout_t vmstat_freebsd_layout[] = {
+static vmstat_layout_t vmstat_freebsd4_layout[] = {
 	{ 0, "cpu_r" },
 	{ 1, "cpu_b" },
 	{ 2, "cpu_w" },
@@ -138,6 +138,30 @@ static vmstat_layout_t vmstat_freebsd_layout[] = {
 	{ -1, NULL }
 };
 
+/* FreeBSD v6 and later, possibly v5 also */
+static vmstat_layout_t vmstat_freebsd_layout[] = {
+	{ 0, "cpu_r" },
+	{ 1, "cpu_b" },
+	{ 2, "cpu_w" },
+	{ 3, "mem_avm" },
+	{ 4, "mem_free" },
+	{ 5, "mem_flt" },
+	{ 6, "mem_re" },
+	{ 7, "mem_pi" },
+	{ 8, "mem_po" },
+	{ 9, "mem_fr" },
+	{ 10, "sr" },
+	{ 11, "dsk_da0" },
+	{ 12, "dsk_pa0" },
+	{ 13, "cpu_int" },
+	{ 14, "cpu_syc" },
+	{ 15, "cpu_csw" },
+	{ 16, "cpu_usr" },
+	{ 17, "cpu_sys" },
+	{ 18, "cpu_idl" },
+	{ -1, NULL }
+};
+
 /* This one matches NetBSD 2.0 */
 /* LARRD 0.43c does not support NetBSD */
 static vmstat_layout_t vmstat_netbsd_layout[] = {
@@ -381,7 +405,25 @@ int do_vmstat_rrd(char *hostname, char *testname, char *classname, char *pagepat
 	  case OS_HPUX: 
 		layout = vmstat_hpux_layout; break;
 	  case OS_FREEBSD:
-		layout = vmstat_freebsd_layout; break;
+		/* 
+		 * Special, because there are two layouts for FreeBSD
+		 * FreeBSD v4.x has 19 fields, later versions of FreeBSD
+		 * are the same as OpenBSD, with 18 fields.
+		 */
+		{
+			char **dsnames = NULL;
+			int dscount, i;
+
+			dscount = rrddatasets(hostname, &dsnames);
+			layout = ((dscount == 19) ? vmstat_freebsd4_layout : vmstat_freebsd_layout);
+
+			if ((dscount > 0) && dsnames) {
+				/* Free the dsnames list */
+				for (i=0; (i<dscount); i++) xfree(dsnames[i]);
+				xfree(dsnames);
+			}
+		}
+		break;
 	  case OS_NETBSD:
 		layout = vmstat_netbsd_layout; break;
 	  case OS_OPENBSD:
