@@ -8,7 +8,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymonnet.c 7902 2016-02-18 19:47:55Z jccleaver $";
+static char rcsid[] = "$Id: xymonnet.c 7967 2016-09-10 03:13:43Z jccleaver $";
 
 #include <limits.h>
 #include <stdio.h>
@@ -1557,13 +1557,32 @@ int decide_color(service_t *service, char *svcname, testitem_t *test, int failgo
 					/* Check that other transport issues didn't occur (like SSL) */
 					if (tcptest && (tcptest->errcode != CONTEST_ENOERROR)) {
 						switch (tcptest->errcode) {
+						  case CONTEST_ETIMEOUT    : 
+							strcpy(cause, "Service listening but unavailable (connect timeout)"); 
+							color = COL_RED; countasdown = 1;
+							break;
+						  case CONTEST_ENOCONN    : 
+							strcpy(cause, "Service listening but unavailable ("); 
+							strcat(cause, strerror(tcptest->connres)); 
+							strcat(cause, ")"); 
+							color = COL_RED; countasdown = 1;
+							break;
+						  case CONTEST_EDNS    : 
+							strcpy(cause, "Service listening but unavailable (DNS error)"); 
+							color = COL_RED; countasdown = 1;
+							break;
+						  case CONTEST_EIO    : 
+							strcpy(cause, "Service listening but unavailable (I/O error)"); 
+							color = COL_RED; countasdown = 1;
+							break;
 						  case CONTEST_ESSL    : 
 							strcpy(cause, "Service listening but unavailable (SSL error)"); 
 							color = COL_RED; countasdown = 1;
 							break;
 						  default		:
-							errprintf("TCPtest error %d seen on open connection for %s.%s\n", tcptest->errcode, test->host, test->service->testname); 
-							// color = COL_RED; countasdown = 1;
+							/* Should not get here */
+							errprintf("-> TCPtest error %d seen on open connection for %s.%s\n", tcptest->errcode, test->host->hostname, test->service->testname); 
+							color = COL_YELLOW;
 							break;
 						}
 						// color = COL_RED; countasdown = 1;
@@ -2065,11 +2084,11 @@ int main(int argc, char *argv[])
 			char *p = strchr(argv[argi], '=');
 			p++; frequenttestlimit = atoi(p);
 		}
-		else if (strcmp(argv[argi], "--timelimit=") == 0) {
+		else if (argnmatch(argv[argi], "--timelimit=")) {
 			char *p = strchr(argv[argi], '=');
 			p++; runtimewarn = atol(p);
 		}
-		else if (strcmp(argv[argi], "--huge=") == 0) {
+		else if (argnmatch(argv[argi], "--huge=")) {
 			char *p = strchr(argv[argi], '=');
 			p++; warnbytesread = atoi(p);
 		}
